Expr

Enum Expr 

pub enum Expr {
    JqPath(String),
    PluginCall {
        name: String,
        args: Vec<AssertionExpr>,
    },
    Literal(Literal),
    Variable(String),
    RegExp {
        pattern: String,
        flags: String,
    },
    Json(String),
    Yaml(String),
    As(Box<Expr>, String),
}
Atomic expressions (leaf nodes).

Variants



JqPath(String)



PluginCall

Fields

name: String


Literal(Literal)



Variable(String)



RegExp

Fields

pattern: String
flags: String


Json(String)



Yaml(String)



As(Box<Expr>, String)

Type annotation: expr:TypeName. Evaluates to expr at runtime, but hints to the type checker that the expression has the given type.